==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebGridClipboardEventEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardEventDetailDescriptionMetadata } from "./WebGridClipboardEventDetailDescriptionMetadata";
import { WebGridClipboardEventEventArgsDescription } from "./WebGridClipboardEventEventArgsDescription";
/**
 * @hidden
 */
export let WebGridClipboardEventEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridClipboardEventEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridClipboardEventEventArgsDescriptionMetadata.a == null) {
                WebGridClipboardEventEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridClipboardEventEventArgsDescriptionMetadata.c(WebGridClipboardEventEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebGridClipboardEventEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridClipboardEventEventArgsDescriptionMetadata.a);
            WebGridClipboardEventDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridClipboardEventEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebGridClipboardEventDetail");
        }
        static d(a) {
            WebGridClipboardEventEventArgsDescriptionMetadata.b(a);
            a.ad("WebGridClipboardEventEventArgs", () => new WebGridClipboardEventEventArgsDescription());
            a.ac("WebGridClipboardEventEventArgs", WebGridClipboardEventEventArgsDescriptionMetadata.a);
        }
    }
    WebGridClipboardEventEventArgsDescriptionMetadata.$t = markType(WebGridClipboardEventEventArgsDescriptionMetadata, 'WebGridClipboardEventEventArgsDescriptionMetadata');
    WebGridClipboardEventEventArgsDescriptionMetadata.a = null;
    return WebGridClipboardEventEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebGridClipboardEventEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardEventDetailDescriptionMetadata } from "./WebGridClipboardEventDetailDescriptionMetadata";
import { WebGridClipboardEventEventArgsDescription } from "./WebGridClipboardEventEventArgsDescription";
/**
 * @hidden
 */
export let WebGridClipboardEventEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridClipboardEventEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridClipboardEventEventArgsDescriptionMetadata.a == null) {
                WebGridClipboardEventEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridClipboardEventEventArgsDescriptionMetadata.c(WebGridClipboardEventEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebGridClipboardEventEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridClipboardEventEventArgsDescriptionMetadata.a);
            WebGridClipboardEventDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridClipboardEventEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebGridClipboardEventDetail");
        }
        static d(a) {
            WebGridClipboardEventEventArgsDescriptionMetadata.b(a);
            a.ae("WebGridClipboardEventEventArgs", () => new WebGridClipboardEventEventArgsDescription());
            a.ad("WebGridClipboardEventEventArgs", WebGridClipboardEventEventArgsDescriptionMetadata.a);
        }
    }
    WebGridClipboardEventEventArgsDescriptionMetadata.$t = markType(WebGridClipboardEventEventArgsDescriptionMetadata, 'WebGridClipboardEventEventArgsDescriptionMetadata');
    WebGridClipboardEventEventArgsDescriptionMetadata.a = null;
    return WebGridClipboardEventEventArgsDescriptionMetadata;
})();
